@@ -1,10 +1,9 @@
 """ A client library for accessing Lightdash API """
-from .client import AuthenticatedClient
-from .client import Client
+from .client import AuthenticatedClient, Client
 
 __all__ = (
     "AuthenticatedClient",
     "Client",
 )
 
-__version__ = "0.618.0"
+__version__ = "0.692.1"
