@@ -1,7 +1,4 @@
-from typing import Any
-from typing import Dict
-from typing import Type
-from typing import TypeVar
+from typing import Any, Dict, Type, TypeVar
 
 import attr
 
